SST Class
===========

.. autoclass:: sstudentt.SST

SST Methods
===========

.. automethod:: sstudentt.SST.d

.. automethod:: sstudentt.SST.p

.. automethod:: sstudentt.SST.q

.. automethod:: sstudentt.SST.r
